@@ -19,9 +19,9 @@
 #include "gtd-provider-todo-txt.h"
 #include "gtd-plugin-todo-txt.h"
 #include "gtd-todo-txt-parser.h"
+
 #include <string.h>
 #include <stdlib.h>
-
 #include <glib/gi18n.h>
 
 
@@ -114,7 +114,9 @@ emit_generic_error (GError *error)
 
   gtd_manager_emit_error_message (gtd_manager_get_default (),
                                   _("Error while opening Todo.txt"),
-                                  error->message);
+                                  error->message,
+                                  NULL,
+                                  NULL);
 }
 
 static void
@@ -263,7 +265,9 @@ gtd_provider_todo_txt_load_tasks (GtdProviderTodoTxt *self)
 
           gtd_manager_emit_error_message (gtd_manager_get_default (),
                                           _("Error while reading a line from Todo.txt"),
-                                          error->message);
+                                          error->message,
+                                          NULL,
+                                          NULL);
           g_error_free (error);
 
           continue;
@@ -378,7 +382,9 @@ gtd_provider_todo_txt_load_source_monitor (GtdProviderTodoTxt *self)
     {
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error while opening the file monitor. Todo.txt will not be monitored"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
       g_clear_error (&error);
       return;
     }
